@@ -685,9 +685,10 @@ class RADecWidget(QWidget):
         marker_cycle = itertools.cycle(sorted(
             set(MarkerSelection.description_character.keys()) -
             set(self.marker_map.values())))
-        for row, calcode in enumerate(sorted(calcodes) + ["SCHED"], 1):
+        for row, calcode in enumerate(sorted(calcodes) + ["SCHED", "Sun"], 1):
             catalog = self.calcode_map.get(calcode, calcode)
-            layout.addWidget(QLabel(catalog, self), row, 0)
+            layout.addWidget(
+                QLabel(catalog if catalog != "" else "No label", self), row, 0)
             widgets = {}
             for column, (column_label, widget_function) in \
                 enumerate(columns.items(), 1):
@@ -724,10 +725,10 @@ class BeamWidget(QWidget):
         return self.image_transfer_function.currentText()
 
     def get_color_map(self):
-        return matplotlib.cm.get_cmap(self.color_map.currentText())
+        return matplotlib.colormaps[self.color_map.currentText()]
 
     def get_contour_colors(self):
-        return matplotlib.cm.get_cmap(self.contour_colors.currentText())
+        return matplotlib.colormaps[self.contour_colors.currentText()]
 
     def get_contours(self):
         return self.contours.isChecked()
@@ -1220,48 +1221,62 @@ class MainWidget(QWidget):
             figure.canvas.manager.set_window_title("RA-Dec Plot")
             label_points = {}
             label_annotations = {}
+
             # catalogs
             calcodes = set(s.srlcalc for s in self.radec_sources)
             for calcode in sorted(calcodes):
-                catalog_label = escape_tex(
-                    self.radec.calcode_map.get(calcode, calcode))
-                if catalog_label == "":
-                    catalog_label = "No label"
-                catalog_sources = [s for s in self.radec_sources
-                                   if s.srlcalc == calcode]
-                xy = np.array(
-                    [[s.srlra, s.srldec] for s in catalog_sources])
-                xy[:, 0] /= parameter.radhr
-                xy[:, 1] /= parameter.raddeg
-                points = axis.scatter(xy[:, 0], xy[:, 1], label=catalog_label,
-                                      **self.radec.get_properties(calcode))
-                points.set_visible(self.radec.get_visible(calcode))
-                label_points[catalog_label] = points
-                
-                # plot source names if they dont clutter (and slow down)
-                # the plot
-                visible = (len(catalog_sources) < 20) and points.get_visible()
-                annotations = []
-                for i, s in enumerate(catalog_sources):
-                    a = axis.annotate(escape_tex(s.srlname), xy=xy[i])
-                    a.set_visible(visible)
-                    annotations.append(a)
-                label_annotations[catalog_label] = annotations
+                if self.radec.get_visible(calcode):
+                    catalog_label = escape_tex(
+                        self.radec.calcode_map.get(calcode, calcode))
+                    if catalog_label == "":
+                        catalog_label = "No label"
+                    catalog_sources = [s for s in self.radec_sources
+                                       if s.srlcalc == calcode]
+                    xy = np.array(
+                        [[s.srlra, s.srldec] for s in catalog_sources])
+                    xy[:, 0] /= parameter.radhr
+                    xy[:, 1] /= parameter.raddeg
+                    label_points[catalog_label] = axis.scatter(
+                        xy[:, 0], xy[:, 1], label=catalog_label,
+                        **self.radec.get_properties(calcode))
 
+                    # plot source names if they dont clutter (and slow down)
+                    # the plot
+                    visible = (len(catalog_sources) < 20)
+                    annotations = []
+                    for i, source in enumerate(catalog_sources):
+                        a = axis.annotate(escape_tex(source.srlname), xy=xy[i])
+                        a.set_visible(visible)
+                        annotations.append(a)
+                    label_annotations[catalog_label] = annotations
 
             # sched
             if self.radec.get_visible("SCHED"):
                 xy = np.array([[s.ra2000, s.d2000] for s in self.sources])
                 xy[:, 0] /= parameter.radhr
                 xy[:, 1] /= parameter.raddeg
+
                 label_points["SCHED"] = axis.scatter(
                     xy[:, 0], xy[:, 1], label="SCHED",
                     **self.radec.get_properties("SCHED"))
+
                 annotations = []
-                for i, s in enumerate(self.sources):
+                for i, source in enumerate(self.sources):
                     annotations.append(
-                        axis.annotate(escape_tex(s.aliases[0]), xy=xy[i]))
-                    label_annotations["SCHED"] = annotations
+                        axis.annotate(escape_tex(source.aliases[0]), xy=xy[i]))
+                label_annotations["SCHED"] = annotations
+
+            # sun
+            if self.radec.get_visible("Sun"):
+                ra, dec = s.sunpos((s.schn1.tfirst +s.schn1.tend) / 2)
+                ra = (ra  / math.pi * 12) % 24
+                dec = dec / math.pi * 180
+
+                label_points["Sun"] = axis.scatter(
+                    [ra], [dec], label="Sun",
+                    **self.radec.get_properties("Sun"))
+
+                label_annotations["Sun"] = [axis.annotate("Sun", xy=[ra, dec])]
 
             axis.set_title("Dec - RA\n"
                            "Click in the legend to show/hide points/labels")
